@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: export.h 370 2004-03-22 18:47:32Z roms $ */
+/* $Id: export.h 892 2005-03-13 19:19:04Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -22,6 +22,10 @@
 #ifndef __TICABLES_EXPORT__
 #define __TICABLES_EXPORT__
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /*
  * Choose one of these calling conventions (override compiler settings)
  */
@@ -47,36 +51,45 @@
 # else
 #  define TICALL
 # endif
+#else
+# define TICALL
+#endif
 
-# if defined(__BORLANDC__)	// BCC32 v5.x (or C++Builder)
+#if defined(HAVE_FVISIBILITY)// GCC 4.0 has introduced the -fvisibility flag (similar to declspec)
+# define TIEXPORT __attribute__ ((visibility("default")))
+
+#elif defined(__WIN32__)
+# if defined(__BORLANDC__)		// BCC32 v5.x (or C++Builder)
 #  if __BORLANDC__ >= 0x0500	// (c) 2001 Thomas Wolf (two@chello.at)
 #   define TIEXPORT
 #  else
 #   define TIEXPORT
 #  endif
 
-# elif defined(_MSC_VER)	// MSVC 5.0 mini
-#  if defined(TICABLES_EXPORTS) || defined(TIFILES_EXPORTS) || defined(TICALCS_EXPORTS)
+# elif defined(_MSC_VER)		// MSVC 5.0 mini
+#  if defined(DLL_EXPORT) || defined(TICABLES_EXPORTS) || defined(TIFILES_EXPORTS) || defined(TICALCS_EXPORTS)
 #   define TIEXPORT __declspec(dllexport)
 #  else
 #   define TIEXPORT __declspec(dllimport)
 #  endif
 
-# elif defined(__MINGW32__)	// MinGW - GCC for Windows, (c) 2002 Kevin Kofler
-#  if defined(DLL_EXPORT)	// defined by the configure script
+# elif defined(__MINGW32__)		// MinGW - GCC for Windows, (c) 2002 Kevin Kofler
+#  if defined(DLL_EXPORT)		// defined by the configure script
 #   define TIEXPORT __declspec(dllexport)
 #  else
-#   define TIEXPORT extern	//__declspec(dllimport)
+#   define TIEXPORT extern
 #  endif
 # endif
 
 #elif defined(__LINUX__) || defined(__BSD__)	// GNU
 # define TIEXPORT extern
-# define TICALL
 
 #else
-# define TIEXPORT		// default
-# define TICALL
+# define TIEXPORT				// default
+#endif
+
+#ifdef __cplusplus
+}
 #endif
 
 // Note: VB requires __sdtcall but __stdcall make entry points disappear -> 
