@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: slv_link.c 801 2004-09-26 11:11:20Z roms $ */
+/* $Id: slv_link.c 1494 2005-07-30 14:41:25Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -316,6 +316,11 @@ int slv_supported()
   	return SUPPORT_ON;
 }
 
+int slv_reset()
+{
+	return slv_open();
+}
+
 int slv_register_cable_1(TicableLinkCable * lc)
 {
   lc->init = slv_init;
@@ -326,6 +331,7 @@ int slv_register_cable_1(TicableLinkCable * lc)
   lc->exit = slv_exit;
   lc->probe = slv_probe;
   lc->check = slv_check;
+  lc->reset = slv_reset;
 
   return 0;
 }
