@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: slv_link2.c 801 2004-09-26 11:11:20Z roms $ */
+/* $Id: slv_link2.c 1494 2005-07-30 14:41:25Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -256,7 +256,7 @@ static int send_fblock2(uint8_t *data, int length)
 {
 	int ret;
 
-	ret = usb_bulk_write(tigl_han, TIGL_BULK_OUT, data, length, to);
+	ret = usb_bulk_write(tigl_han, TIGL_BULK_OUT, (char *)data, length, to);
 
 	if(ret == -ETIMEDOUT) {
 		printl1(2, "usb_bulk_write (%s).\n", usb_strerror());
@@ -412,7 +412,7 @@ int slv_get2(uint8_t * data)
   	if (nBytesRead2 <= 0) {
 	    	toSTART(clk);
 	    	do {
-	      		ret = usb_bulk_read(tigl_han, TIGL_BULK_IN, rBuf2, 
+	      		ret = usb_bulk_read(tigl_han, TIGL_BULK_IN, (char*)rBuf2, 
 					    max_ps, to);
 					    
 	      		if (toELAPSED(clk, time_out))
@@ -473,8 +473,8 @@ int slv_check2(int *status)
 
 	    	toSTART(clk);
 	    	do {
-	      		ret = usb_bulk_read(tigl_han, TIGL_BULK_IN, rBuf2, 
-					    max_ps, to);
+	      		ret = usb_bulk_read(tigl_han, TIGL_BULK_IN, 
+					    (char*)rBuf2, max_ps, to);
 					    
 	      		if (toELAPSED(clk, time_out))
 				return ERR_READ_TIMEOUT;
@@ -524,6 +524,18 @@ int slv_supported2()
   	return SUPPORT_ON;
 }
 
+int slv_reset2()
+{
+#if !defined(__BSD__)
+	{
+		/* Reset both endpoints */
+		int ret = reset_pipes();
+		if(ret) return ret;
+	}
+#endif
+	return 0;
+}
+
 int slv_register_cable_2(TicableLinkCable * lc)
 {
   lc->init = slv_init2;
@@ -534,6 +546,7 @@ int slv_register_cable_2(TicableLinkCable * lc)
   lc->exit = slv_exit2;
   lc->probe = slv_probe2;
   lc->check = slv_check2;
+  lc->reset = slv_reset2;
 
   return 0;
 }
