@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tig_link.c 720 2004-05-22 18:06:40Z roms $ */
+/* $Id: tig_link.c 1494 2005-07-30 14:41:25Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -250,6 +250,11 @@ int tig_supported()
   	return SUPPORT_ON;
 }
 
+int tig_reset()
+{
+	return tig_open();
+}
+
 int tig_register_cable(TicableLinkCable * lc, TicableMethod method)
 {
   lc->init = tig_init;
@@ -260,6 +265,7 @@ int tig_register_cable(TicableLinkCable * lc, TicableMethod method)
   lc->exit = tig_exit;
   lc->probe = tig_probe;
   lc->check = tig_check;
+  lc->reset = tig_reset;
 
   return 0;
 }
