@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: vti_link.c 720 2004-05-22 18:06:40Z roms $ */
+/* $Id: vti_link.c 1494 2005-07-30 14:41:25Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -261,6 +261,11 @@ int vti_supported()
 #endif
 }
 
+int vti_reset()
+{
+	return vti_open();
+}
+
 int vti_register_cable(TicableLinkCable * lc)
 {
   lc->init = vti_init;
@@ -271,6 +276,7 @@ int vti_register_cable(TicableLinkCable * lc)
   lc->exit = vti_exit;
   lc->probe = vti_probe;
   lc->check = vti_check;
+  lc->reset = vti_reset;
 
   return 0;
 }
