@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: logging.c 665 2004-04-29 18:25:16Z tijl $ */
+/* $Id: logging.c 1358 2005-07-12 07:42:17Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -144,8 +144,8 @@ int stop_logging()
   	if (log2 != NULL)
     		fclose(log2);
 
-  	free(fn1);
-  	free(fn2);
+  	//free(fn1);
+  	//free(fn2);
 
   	return 0;
 }
