@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: logging.h 370 2004-03-22 18:47:32Z roms $ */
+/* $Id: logging.h 665 2004-04-29 18:25:16Z tijl $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -36,7 +36,7 @@ int start_void();
 int log_void();
 int stop_void();
 
-#ifdef LOGGING_ENABLED
+#ifdef ENABLE_LOGGING
 # define START_LOGGING(); start_logging();
 # define LOG_DATA(d);     log_data(d);
 # define STOP_LOGGING();  stop_logging();
