@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: ticables.h 651 2004-04-25 15:22:07Z roms $ */
+/* $Id: ticables.h 825 2004-12-27 21:49:52Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -22,9 +22,17 @@
 #ifndef __TICABLES_H__
 #define __TICABLES_H__
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "cabl_def.h"
 #include "cabl_int.h"
 #include "cabl_err.h"
 #include "cabl_ver.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
