@@ -330,6 +330,12 @@ int slv_supported()
   return SUPPORT_ON;
 }
 
+int slv_reset()
+{
+	dynTiglUsbFlush();
+	return 0;
+}
+
 int slv_register_cable_1(TicableLinkCable * lc)
 {
   lc->init = slv_init;
@@ -340,6 +346,7 @@ int slv_register_cable_1(TicableLinkCable * lc)
   lc->exit = slv_exit;
   lc->probe = slv_probe;
   lc->check = slv_check;
+  lc->reset = slv_reset;
 
   return 0;
 }
