@@ -82,11 +82,14 @@ int tie_init(void)
     printl1(2, _("invalid io_address parameter passed to libticables.\n"));
     io_address = 2;
   } 
-  else 
-  {
+
     p = io_address - 1;
     ref_cnt++;
-  }
+	printf("ref_cnt = %i\n", ref_cnt);
+
+/* Automatic setting: if port #1 is already used, bind to port #2 */
+    if(ref_cnt == 2 && p == 0)
+	p = 1;
 
   /* Create a FileMapping objects */
   hSendBuf = CreateFileMapping((HANDLE) (-1), NULL, PAGE_READWRITE, 0, sizeof(LinkBuffer), (LPCTSTR) name[2 * p + 0]);
@@ -122,6 +125,8 @@ int tie_exit()
   if (hRecvBuf) 
     UnmapViewOfFile(pRecvBuf);
 
+  ref_cnt--;
+
   return 0;
 }
 
@@ -147,6 +152,8 @@ int tie_put(uint8_t data)
 
   //if(!hMap)
   //      return ERR_OPEN_FILE_MAP;
+  if(ref_cnt < 2)
+     return 0;
 
   tdr.count++;
   LOG_DATA(data);
@@ -171,6 +178,8 @@ int tie_get(uint8_t * data)
 
   //if(!hMap)
   //      return ERR_OPEN_FILE_MAP;
+  if(ref_cnt < 2)
+     return 0;
 
   //printl1(0, "s: %i, e: %i\n", pSendBuf->start, pSendBuf->end);
 
@@ -196,6 +205,9 @@ int tie_get(uint8_t * data)
 
 int tie_check(int *status)
 {
+	if(ref_cnt < 2)
+     return 0;
+
   /* Check if positions are the same */
   if (pRecvBuf->start == pRecvBuf->end)
     *status = STATUS_NONE;
@@ -215,6 +227,13 @@ int tie_supported()
   return SUPPORT_ON;
 }
 
+int tie_reset()
+{
+	pSendBuf->start = pSendBuf->end = 0;
+	pRecvBuf->start = pRecvBuf->end = 0;
+	return 0;
+}
+
 int tie_register_cable(TicableLinkCable * lc)
 {
   lc->init = tie_init;
@@ -225,6 +244,7 @@ int tie_register_cable(TicableLinkCable * lc)
   lc->exit = tie_exit;
   lc->probe = tie_probe;
   lc->check = tie_check;
+  lc->reset = tie_reset;
 
   return 0;
 }
